@@ -14,94 +14,85 @@ select_prediction_method <- function(fun,
                                      vcov.type,
                                      vcov.args,
                                      condition,
+                                     interval,
                                      ...) {
   # get link-inverse-function
   linv <- insight::link_inverse(model)
   if (is.null(linv)) linv <- function(x) x
 
   if (fun == "svyglm") {
-    # survey-objects -----
     fitfram <- get_predictions_svyglm(model, expanded_frame, ci.lvl, linv, ...)
   } else if (fun == "svyglm.nb") {
-    # survey-glm.nb-objects -----
-    fitfram <- get_predictions_svyglmnb(model, expanded_frame, ci.lvl, linv, fun, typical, terms, vcov.fun, vcov.type, vcov.args, condition, ...)
+    fitfram <- get_predictions_svyglmnb(model, expanded_frame, ci.lvl, linv, fun, typical, terms, vcov.fun, vcov.type, vcov.args, condition, interval, ...)
   } else if (fun == "stanreg") {
-    # stan-objects -----
     fitfram <- get_predictions_stan(model, expanded_frame, ci.lvl, type, faminfo, ppd, terms, ...)
   } else if (fun == "brmsfit") {
-    # brms-objects -----
     fitfram <- get_predictions_stan(model, expanded_frame, ci.lvl, type, faminfo, ppd, terms, ...)
   } else if (fun == "coxph" && type != "surv" && type != "cumhaz") {
-    # coxph-objects -----
-    fitfram <- get_predictions_coxph(model, expanded_frame, ci.lvl, ...)
+    fitfram <- get_predictions_coxph(model, expanded_frame, ci.lvl, typical, fun, vcov.fun, vcov.type, vcov.args, condition, interval, ...)
   } else if (fun == "coxph" && type %in% c("surv", "cumhaz")) {
-    # coxph-objects -----
     fitfram <- get_predictions_survival(model, expanded_frame, ci.lvl, type, terms, ...)
+  } else if (fun == "ols") {
+    fitfram <- get_predictions_ols(model, expanded_frame, ci.lvl, ...)
   } else if (fun == "lrm") {
-    # lrm-objects -----
     fitfram <- get_predictions_lrm(model, expanded_frame, ci.lvl, linv, ...)
   } else if (fun == "glmmTMB") {
-    # glmmTMB-objects -----
     fitfram <- get_predictions_glmmTMB(model, expanded_frame, ci.lvl, linv, type, terms, typical, condition, ...)
   } else if (fun %in% c("lmer", "nlmer", "glmer")) {
-    # merMod-objects  -----
     fitfram <- get_predictions_merMod(model, expanded_frame, ci.lvl, linv, type, terms, typical, condition, ...)
+  } else if (fun == "geeglm") {
+    fitfram <- get_predictions_geeglm(model, expanded_frame, ...)
+  } else if (fun == "gamlss") {
+    fitfram <- get_predictions_gamlss(model, expanded_frame, ci.lvl, linv, terms, fun, typical, condition, ...)
   } else if (fun == "gam") {
-    # gam-objects -----
     fitfram <- get_predictions_gam(model, expanded_frame, ci.lvl, linv, ...)
   } else if (fun == "Gam") {
-    # Gam-objects -----
     fitfram <- get_predictions_Gam(model, expanded_frame, ci.lvl, linv, typical, terms, fun, condition, ...)
   # } else if (fun == "vgam") {
-  # vgam-objects -----
   # fitfram <- get_predictions_vgam(model, expanded_frame, ci.lvl, linv, ...)
   } else if (fun == "vglm") {
-    # vgam-objects -----
     fitfram <- get_predictions_vglm(model, expanded_frame, ci.lvl, linv, ...)
+  } else if (fun == "tobit") {
+    fitfram <- get_predictions_tobit(model, expanded_frame, ci.lvl, linv, ...)
   } else if (fun %in% c("lme", "gls", "plm")) {
-    # lme-objects -----
-    fitfram <- get_predictions_lme(model, expanded_frame, ci.lvl, linv, type, terms, typical, condition, ...)
+    fitfram <- get_predictions_lme(model, expanded_frame, ci.lvl, linv, type, terms, typical, fun, vcov.fun, vcov.type, vcov.args, condition, ...)
   } else if (fun == "gee") {
-    # gee-objects -----
     fitfram <- get_predictions_gee(model, terms, ...)
   } else if (fun == "multinom") {
-    # multinom-objects -----
     fitfram <- get_predictions_multinom(model, expanded_frame, ci.lvl, linv, typical, terms, fun, ...)
   } else if (fun == "clmm") {
-    # clmm-objects -----
     fitfram <- get_predictions_clmm(model, terms, typical, condition, ci.lvl, linv, ...)
   } else if (fun == "clm") {
-    # clm-objects -----
     fitfram <- get_predictions_clm(model, expanded_frame, ci.lvl, linv, ...)
   } else if (fun == "clm2") {
-    # clm2-objects -----
     fitfram <- get_predictions_clm2(model, expanded_frame, ci.lvl, linv, ...)
   } else if (fun == "Zelig-relogit") {
-    # Zelig-relogit-objects -----
     fitfram <- get_predictions_zelig(model, expanded_frame, ci.lvl, linv, ...)
   } else if (fun == "polr") {
-    # polr-objects -----
-    fitfram <- get_predictions_polr(model, expanded_frame, ci.lvl, linv, typical, terms, fun, condition, ...)
+    fitfram <- get_predictions_polr(model, expanded_frame, ci.lvl, linv, typical, terms, fun, vcov.fun, vcov.type, vcov.args, condition, interval, ...)
   } else if (fun %in% c("betareg", "truncreg", "ivreg", "vgam")) {
-    # betareg, truncreg-objects -----
-    fitfram <- get_predictions_generic2(model, expanded_frame, ci.lvl, linv, type, fun, typical, terms, vcov.fun, vcov.type, vcov.args, condition, ...)
+    fitfram <- get_predictions_generic2(model, expanded_frame, ci.lvl, linv, type, fun, typical, terms, vcov.fun, vcov.type, vcov.args, condition, interval, ...)
   } else if (fun %in% c("zeroinfl", "hurdle", "zerotrunc")) {
-    # zeroinfl and hurdle-objects -----
     fitfram <- get_predictions_zeroinfl(model, expanded_frame, ci.lvl, linv, type, fun, typical, terms, vcov.fun, vcov.type, vcov.args, condition, ...)
-  } else if (fun %in% c("glm", "glm.nb", "glmRob")) {
-    # glm-objects -----
-    fitfram <- get_predictions_glm(model, expanded_frame, ci.lvl, linv, typical, fun, terms, vcov.fun, vcov.type, vcov.args, condition, ...)
+  } else if (fun %in% c("glm", "glm.nb")) {
+    fitfram <- get_predictions_glm(model, expanded_frame, ci.lvl, linv, typical, fun, terms, vcov.fun, vcov.type, vcov.args, condition, interval, ...)
+  } else if (fun %in% c("rq")) {
+    fitfram <- get_predictions_rq(model, expanded_frame, ci.lvl, ...)
+  } else if (fun %in% c("lmrob")) {
+    fitfram <- get_predictions_lmrob_base(model, expanded_frame, ci.lvl, ...)
+  } else if (fun %in% c("glmrob")) {
+    fitfram <- get_predictions_glmrob_base(model, expanded_frame, ci.lvl, linv, ...)
+  } else if (fun %in% c("glmRob")) {
+    fitfram <- get_predictions_glmRob(model, expanded_frame, ci.lvl, linv, typical, fun, terms, vcov.fun, vcov.type, vcov.args, condition, interval, ...)
+  } else if (fun == "logistf") {
+    fitfram <- get_predictions_logistf(model, expanded_frame, terms, ...)
   } else if (fun == "lm") {
-    # lm-objects -----
-    fitfram <- get_predictions_lm(model, expanded_frame, ci.lvl, fun, typical, terms, vcov.fun, vcov.type, vcov.args, condition, ...)
+    fitfram <- get_predictions_lm(model, expanded_frame, ci.lvl, fun, typical, terms, vcov.fun, vcov.type, vcov.args, condition, interval, ...)
   } else if (fun == "MixMod") {
-    # MixMod-objects -----
     fitfram <- get_predictions_MixMod(model, expanded_frame, ci.lvl, linv, type, terms, typical, condition, ...)
   } else if (fun == "MCMCglmm") {
-    # MCMCglmm-objects -----
     fitfram <- get_predictions_MCMCglmm(model, expanded_frame, ci.lvl, ...)
   } else {
-    # general-objects -----
     fitfram <- get_predictions_generic(model, expanded_frame, linv, ...)
   }
 
@@ -109,7 +100,7 @@ select_prediction_method <- function(fun,
 }
 
 
-get_base_fitfram <- function(model, fitfram, linv, prdat, se, ci.lvl, fun, typical, terms, vcov.fun, vcov.type, vcov.args, condition = NULL) {
+get_base_fitfram <- function(model, fitfram, linv, prdat, se, ci.lvl, fun, typical, terms, vcov.fun, vcov.type, vcov.args, condition = NULL, interval = NULL) {
 
   # compute ci, two-ways
 
@@ -129,17 +120,20 @@ get_base_fitfram <- function(model, fitfram, linv, prdat, se, ci.lvl, fun, typic
 
   # get standard errors, if computed
 
-  if (obj_has_name(prdat, "se.fit"))
+  if (obj_has_name(prdat, "se.fit")) {
     se.fit <- prdat$se.fit
-  else
+    # reset interval, since we have normal confidence intervals already here
+    if (interval == "confidence") interval <- NULL
+  } else {
     se.fit <- NULL
+  }
 
   # get predicted values, on link-scale
   fitfram$predicted <- .predicted
 
   # did user request robust standard errors?
 
-  if (!is.null(vcov.fun)) {
+  if (!is.null(vcov.fun) || (!is.null(interval) && se)) {
     se.pred <-
       get_se_from_vcov(
         model = model,
@@ -150,7 +144,8 @@ get_base_fitfram <- function(model, fitfram, linv, prdat, se, ci.lvl, fun, typic
         vcov.fun = vcov.fun,
         vcov.type = vcov.type,
         vcov.args = vcov.args,
-        condition = condition
+        condition = condition,
+        interval = interval
       )
 
     if (!is.null(se.pred)) {
@@ -161,6 +156,8 @@ get_base_fitfram <- function(model, fitfram, linv, prdat, se, ci.lvl, fun, typic
       se.fit <- NULL
       se <- FALSE
     }
+  } else {
+    se.pred <- NULL
   }
 
 
@@ -171,6 +168,8 @@ get_base_fitfram <- function(model, fitfram, linv, prdat, se, ci.lvl, fun, typic
     fitfram$conf.high <- linv(fitfram$predicted + stats::qnorm(ci) * se.fit)
     # copy standard errors
     attr(fitfram, "std.error") <- se.fit
+    if (!is.null(se.pred))
+      attr(fitfram, "prediction.interval") <- attr(se.pred, "prediction_interval")
   } else {
     # No CI
     fitfram$conf.low <- NA
