@@ -1,6 +1,6 @@
 .runThisTest <- Sys.getenv("RunAllggeffectsTests") == "yes"
 
-if (.runThisTest) {
+if (.runThisTest && Sys.getenv("USER") != "travis") {
   if (require("testthat") && require("ggeffects") && require("MCMCglmm")) {
     set.seed(123)
     data(PlodiaPO)
@@ -16,12 +16,12 @@ if (.runThisTest) {
 
     test_that("ggpredict", {
       p <- ggpredict(m1, "plate")
-      expect_equal(p$predicted[1], 1.057289, tolerance = 1e-3)
+      expect_equal(p$predicted[1], 1.056156, tolerance = 1e-4)
     })
 
     test_that("ggemmeans", {
       p <- ggemmeans(m1, "plate")
-      expect_equal(p$predicted[1], 1.057427, tolerance = 1e-3)
+      expect_equal(p$predicted[1], 1.055668, tolerance = 1e-4)
     })
   }
 }
