@@ -18,6 +18,7 @@ if (suppressWarnings(
     p <- plot(pr, ci = FALSE)
     p <- plot(pr, ci = TRUE, ci.style = "dot")
     p <- plot(pr, rawdata = TRUE)
+    p <- plot(pr, rawdata = TRUE, jitter = FALSE)
     p <- plot(pr, colors = "bw")
     p <- plot(pr, colors = "gs")
 
@@ -26,6 +27,7 @@ if (suppressWarnings(
     p <- plot(pr, ci = FALSE)
     p <- plot(pr, ci = TRUE, ci.style = "dot")
     p <- plot(pr, rawdata = TRUE)
+    p <- plot(pr, rawdata = TRUE, jitter = 0)
     p <- plot(pr, facets = TRUE)
     p <- plot(pr, facets = FALSE)
     p <- plot(pr, use.theme = FALSE)
